from wenxin_api.api.base_api import BaseObject, APIBaseObject
from wenxin_api.api.base_api import CreatableAPIObject, DeletableAPIObject, ListableAPIObject
from wenxin_api.api.task_api import Task
from wenxin_api.api.model_api import Model
from wenxin_api.api.dataset_api import Dataset
from wenxin_api.api.train_api import Train